Title: [258412] trunk
Revision
258412
Author
annu...@yandex.ru
Date
2020-03-13 11:10:58 -0700 (Fri, 13 Mar 2020)

Log Message

[CMake] Eleminate mismatches between Find* module names and variables they set
https://bugs.webkit.org/show_bug.cgi?id=208948

Reviewed by Michael Catanzaro.

.:

* Source/cmake/FindLibseccomp.cmake:
* Source/cmake/FindWPEBackend_fdo.cmake: Renamed from Source/cmake/FindWPEBackend-fdo.cmake.
* Source/cmake/OptionsGTK.cmake:
* Source/cmake/OptionsWPE.cmake:

Source/ThirdParty/libwebrtc:

* CMakeLists.txt:
* cmake/FindAlsaLib.cmake:
* cmake/FindLibEvent.cmake:
* cmake/FindLibOpus.cmake: Renamed from Source/ThirdParty/libwebrtc/cmake/FindOpus.cmake.
* cmake/FindLibVpx.cmake: Renamed from Source/ThirdParty/libwebrtc/cmake/FindVpx.cmake.

Tools:

* wpe/backends/CMakeLists.txt:

Modified Paths

Added Paths

Removed Paths

Diff

Modified: trunk/ChangeLog (258411 => 258412)


--- trunk/ChangeLog	2020-03-13 17:56:28 UTC (rev 258411)
+++ trunk/ChangeLog	2020-03-13 18:10:58 UTC (rev 258412)
@@ -1,3 +1,15 @@
+2020-03-13  Konstantin Tokarev  <annu...@yandex.ru>
+
+        [CMake] Eleminate mismatches between Find* module names and variables they set
+        https://bugs.webkit.org/show_bug.cgi?id=208948
+
+        Reviewed by Michael Catanzaro.
+
+        * Source/cmake/FindLibseccomp.cmake:
+        * Source/cmake/FindWPEBackend_fdo.cmake: Renamed from Source/cmake/FindWPEBackend-fdo.cmake.
+        * Source/cmake/OptionsGTK.cmake:
+        * Source/cmake/OptionsWPE.cmake:
+
 2020-03-12  Konstantin Tokarev  <annu...@yandex.ru>
 
         [CMake] Find modules should find pkg-config with find_package(PkgConfig QUIET)

Modified: trunk/Source/ThirdParty/libwebrtc/CMakeLists.txt (258411 => 258412)


--- trunk/Source/ThirdParty/libwebrtc/CMakeLists.txt	2020-03-13 17:56:28 UTC (rev 258411)
+++ trunk/Source/ThirdParty/libwebrtc/CMakeLists.txt	2020-03-13 18:10:58 UTC (rev 258412)
@@ -1,7 +1,7 @@
 
 set (CMAKE_MODULE_PATH "${CMAKE_CURRENT_SOURCE_DIR}/cmake")
 
-find_package(Vpx 1.7.0)
+find_package(LibVpx 1.7.0)
 if (NOT LIBVPX_FOUND)
     message(FATAL_ERROR "libvpx is needed for USE_LIBWEBRTC.")
 endif ()
@@ -16,7 +16,7 @@
     message(FATAL_ERROR "alsa-lib is needed for USE_LIBWEBRTC.")
 endif ()
 
-find_package(Opus 1.3)
+find_package(LibOpus 1.3)
 if (NOT LIBOPUS_FOUND)
     message(FATAL_ERROR "libopus is needed for USE_LIBWEBRTC.")
 endif ()
@@ -1551,11 +1551,11 @@
     Source/webrtc/modules/audio_coding/codecs/isac/main/include
 )
 
-target_link_libraries(webrtc ${VPX_LIBRARY})
+target_link_libraries(webrtc ${LIBVPX_LIBRARY})
 
-target_link_libraries(webrtc ${EVENT_LIBRARY})
+target_link_libraries(webrtc ${LIBEVENT_LIBRARY})
 
-target_link_libraries(webrtc ${OPUS_LIBRARY})
+target_link_libraries(webrtc ${LIBOPUS_LIBRARY})
 
 # libsrtp package compilation
 set(libsrtp_SOURCES

Modified: trunk/Source/ThirdParty/libwebrtc/ChangeLog (258411 => 258412)


--- trunk/Source/ThirdParty/libwebrtc/ChangeLog	2020-03-13 17:56:28 UTC (rev 258411)
+++ trunk/Source/ThirdParty/libwebrtc/ChangeLog	2020-03-13 18:10:58 UTC (rev 258412)
@@ -1,3 +1,16 @@
+2020-03-13  Konstantin Tokarev  <annu...@yandex.ru>
+
+        [CMake] Eleminate mismatches between Find* module names and variables they set
+        https://bugs.webkit.org/show_bug.cgi?id=208948
+
+        Reviewed by Michael Catanzaro.
+
+        * CMakeLists.txt:
+        * cmake/FindAlsaLib.cmake:
+        * cmake/FindLibEvent.cmake:
+        * cmake/FindLibOpus.cmake: Renamed from Source/ThirdParty/libwebrtc/cmake/FindOpus.cmake.
+        * cmake/FindLibVpx.cmake: Renamed from Source/ThirdParty/libwebrtc/cmake/FindVpx.cmake.
+
 2020-03-02  Alan Coon  <alanc...@apple.com>
 
         Add new Mac target numbers

Modified: trunk/Source/ThirdParty/libwebrtc/cmake/FindAlsaLib.cmake (258411 => 258412)


--- trunk/Source/ThirdParty/libwebrtc/cmake/FindAlsaLib.cmake	2020-03-13 17:56:28 UTC (rev 258411)
+++ trunk/Source/ThirdParty/libwebrtc/cmake/FindAlsaLib.cmake	2020-03-13 18:10:58 UTC (rev 258412)
@@ -30,4 +30,4 @@
 pkg_check_modules(PC_ALSALIB alsa)
 
 include(FindPackageHandleStandardArgs)
-find_package_handle_standard_args(Alsalib DEFAULT_MSG PC_ALSALIB_VERSION)
+find_package_handle_standard_args(AlsaLib DEFAULT_MSG PC_ALSALIB_VERSION)

Modified: trunk/Source/ThirdParty/libwebrtc/cmake/FindLibEvent.cmake (258411 => 258412)


--- trunk/Source/ThirdParty/libwebrtc/cmake/FindLibOpus.cmake	                        (rev 0)
+++ trunk/Source/ThirdParty/libwebrtc/cmake/FindLibOpus.cmake	2020-03-13 18:10:58 UTC (rev 258412)
@@ -0,0 +1,46 @@
+# - Try to find opus.
+# Once done, this will define
+#
+#  LIBOPUS_FOUND - system has opus.
+#  LIBOPUS_LIBRARY - link this to use opus.
+#
+# Copyright (C) 2018 Igalia S.L.
+#
+# Redistribution and use in source and binary forms, with or without
+# modification, are permitted provided that the following conditions
+# are met:
+# 1.  Redistributions of source code must retain the above copyright
+#     notice, this list of conditions and the following disclaimer.
+# 2.  Redistributions in binary form must reproduce the above copyright
+#     notice, this list of conditions and the following disclaimer in the
+#     documentation and/or other materials provided with the distribution.
+#
+# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER AND ITS CONTRIBUTORS ``AS
+# IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
+# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR ITS
+# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
+# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
+# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
+# WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
+# OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
+# ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+
+find_package(PkgConfig)
+pkg_check_modules(PC_LIBOPUS opus)
+
+find_library(LIBOPUS_LIBRARY
+    NAME opus
+    HINTS ${PC_LIBOPUS_LIBDIR}
+)
+
+include(FindPackageHandleStandardArgs)
+find_package_handle_standard_args(LibOpus
+    REQUIRED_VARS LIBOPUS_LIBRARY
+    FOUND_VAR LIBOPUS_FOUND
+    VERSION_VAR PC_LIBOPUS_VERSION)
+
+mark_as_advanced(
+    LIBOPUS_LIBRARY
+)

Copied: trunk/Source/ThirdParty/libwebrtc/cmake/FindLibVpx.cmake (from rev 258411, trunk/Source/ThirdParty/libwebrtc/cmake/FindVpx.cmake) (0 => 258412)


--- trunk/Source/ThirdParty/libwebrtc/cmake/FindLibVpx.cmake	                        (rev 0)
+++ trunk/Source/ThirdParty/libwebrtc/cmake/FindLibVpx.cmake	2020-03-13 18:10:58 UTC (rev 258412)
@@ -0,0 +1,46 @@
+# - Try to find libvpx.
+# Once done, this will define
+#
+#  LIBVPX_FOUND - system has libvpx.
+#  LIBVPX_LIBRARY - link this to use libvpx.
+#
+# Copyright (C) 2018 Igalia S.L.
+#
+# Redistribution and use in source and binary forms, with or without
+# modification, are permitted provided that the following conditions
+# are met:
+# 1.  Redistributions of source code must retain the above copyright
+#     notice, this list of conditions and the following disclaimer.
+# 2.  Redistributions in binary form must reproduce the above copyright
+#     notice, this list of conditions and the following disclaimer in the
+#     documentation and/or other materials provided with the distribution.
+#
+# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER AND ITS CONTRIBUTORS ``AS
+# IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
+# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR ITS
+# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
+# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
+# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
+# WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
+# OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
+# ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+
+find_package(PkgConfig)
+pkg_check_modules(PC_LIBVPX vpx)
+
+find_library(LIBVPX_LIBRARY
+    NAME vpx
+    HINTS ${PC_LIBVPX_LIBDIR}
+)
+
+include(FindPackageHandleStandardArgs)
+find_package_handle_standard_args(LibVpx
+    REQUIRED_VARS LIBVPX_LIBRARY
+    FOUND_VAR LIBVPX_FOUND
+    VERSION_VAR PC_LIBVPX_VERSION)
+
+mark_as_advanced(
+    LIBVPX_LIBRARY
+)

Deleted: trunk/Source/ThirdParty/libwebrtc/cmake/FindOpus.cmake (258411 => 258412)


--- trunk/Source/ThirdParty/libwebrtc/cmake/FindOpus.cmake	2020-03-13 17:56:28 UTC (rev 258411)
+++ trunk/Source/ThirdParty/libwebrtc/cmake/FindOpus.cmake	2020-03-13 18:10:58 UTC (rev 258412)
@@ -1,46 +0,0 @@
-# - Try to find opus.
-# Once done, this will define
-#
-#  LIBOPUS_FOUND - system has opus.
-#  OPUS_LIBRARY - link this to use opus.
-#
-# Copyright (C) 2018 Igalia S.L.
-#
-# Redistribution and use in source and binary forms, with or without
-# modification, are permitted provided that the following conditions
-# are met:
-# 1.  Redistributions of source code must retain the above copyright
-#     notice, this list of conditions and the following disclaimer.
-# 2.  Redistributions in binary form must reproduce the above copyright
-#     notice, this list of conditions and the following disclaimer in the
-#     documentation and/or other materials provided with the distribution.
-#
-# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER AND ITS CONTRIBUTORS ``AS
-# IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
-# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
-# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR ITS
-# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
-# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
-# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
-# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
-# WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
-# OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
-# ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-
-find_package(PkgConfig)
-pkg_check_modules(PC_LIBOPUS opus)
-
-find_library(OPUS_LIBRARY
-    NAME opus
-    HINTS ${PC_LIBOPUS_LIBDIR}
-)
-
-include(FindPackageHandleStandardArgs)
-find_package_handle_standard_args(LibOpus
-    REQUIRED_VARS OPUS_LIBRARY
-    FOUND_VAR LIBOPUS_FOUND
-    VERSION_VAR PC_LIBOPUS_VERSION)
-
-mark_as_advanced(
-    OPUS_LIBRARY
-)

Deleted: trunk/Source/ThirdParty/libwebrtc/cmake/FindVpx.cmake (258411 => 258412)


--- trunk/Source/ThirdParty/libwebrtc/cmake/FindVpx.cmake	2020-03-13 17:56:28 UTC (rev 258411)
+++ trunk/Source/ThirdParty/libwebrtc/cmake/FindVpx.cmake	2020-03-13 18:10:58 UTC (rev 258412)
@@ -1,46 +0,0 @@
-# - Try to find libvpx.
-# Once done, this will define
-#
-#  LIBVPX_FOUND - system has libvpx.
-#  VPX_LIBRARY - link this to use libvpx.
-#
-# Copyright (C) 2018 Igalia S.L.
-#
-# Redistribution and use in source and binary forms, with or without
-# modification, are permitted provided that the following conditions
-# are met:
-# 1.  Redistributions of source code must retain the above copyright
-#     notice, this list of conditions and the following disclaimer.
-# 2.  Redistributions in binary form must reproduce the above copyright
-#     notice, this list of conditions and the following disclaimer in the
-#     documentation and/or other materials provided with the distribution.
-#
-# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER AND ITS CONTRIBUTORS ``AS
-# IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
-# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
-# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR ITS
-# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
-# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
-# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
-# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
-# WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
-# OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
-# ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-
-find_package(PkgConfig)
-pkg_check_modules(PC_LIBVPX vpx)
-
-find_library(VPX_LIBRARY
-    NAME vpx
-    HINTS ${PC_LIBVPX_LIBDIR}
-)
-
-include(FindPackageHandleStandardArgs)
-find_package_handle_standard_args(LibVpx
-    REQUIRED_VARS VPX_LIBRARY
-    FOUND_VAR LIBVPX_FOUND
-    VERSION_VAR PC_LIBVPX_VERSION)
-
-mark_as_advanced(
-    VPX_LIBRARY
-)

Modified: trunk/Source/cmake/FindLibseccomp.cmake (258411 => 258412)


--- trunk/Source/cmake/FindLibseccomp.cmake	2020-03-13 17:56:28 UTC (rev 258411)
+++ trunk/Source/cmake/FindLibseccomp.cmake	2020-03-13 18:10:58 UTC (rev 258412)
@@ -42,7 +42,7 @@
 )
 
 include(FindPackageHandleStandardArgs)
-find_package_handle_standard_args(LIBSECCOMP
+find_package_handle_standard_args(Libseccomp
     REQUIRED_VARS LIBSECCOMP_LIBRARIES
     FOUND_VAR LIBSECCOMP_FOUND
     VERSION_VAR PC_LIBSECCOMP_VERSION)

Deleted: trunk/Source/cmake/FindWPEBackend-fdo.cmake (258411 => 258412)


--- trunk/Source/cmake/FindWPEBackend-fdo.cmake	2020-03-13 17:56:28 UTC (rev 258411)
+++ trunk/Source/cmake/FindWPEBackend-fdo.cmake	2020-03-13 18:10:58 UTC (rev 258412)
@@ -1,47 +0,0 @@
-# - Try to find WPEBackend-fdo.
-# Once done, this will define
-#
-#  WPEBACKEND_FDO_FOUND - system has WPEBackend-fdo.
-#  WPEBACKEND_FDO_INCLUDE_DIRS - the WPEBackend-fdo include directories
-#  WPEBACKEND_FDO_LIBRARIES - link these to use WPEBackend-fdo.
-#
-# Copyright (C) 2016 Igalia S.L.
-#
-# Redistribution and use in source and binary forms, with or without
-# modification, are permitted provided that the following conditions
-# are met:
-# 1.  Redistributions of source code must retain the above copyright
-#     notice, this list of conditions and the following disclaimer.
-# 2.  Redistributions in binary form must reproduce the above copyright
-#     notice, this list of conditions and the following disclaimer in the
-#     documentation and/or other materials provided with the distribution.
-#
-# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER AND ITS CONTRIBUTORS ``AS
-# IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
-# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
-# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR ITS
-# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
-# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
-# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
-# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
-# WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
-# OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
-# ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-
-find_package(PkgConfig QUIET)
-pkg_check_modules(PC_WPEBACKEND_FDO QUIET wpebackend-fdo-1.0)
-
-find_path(WPEBACKEND_FDO_INCLUDE_DIRS
-    NAMES wpe/fdo.h
-    HINTS ${PC_WPEBACKEND_FDO_INCLUDEDIR} ${PC_WPEBACKEND_FDO_INCLUDE_DIRS}
-)
-
-find_library(WPEBACKEND_FDO_LIBRARIES
-    NAMES WPEBackend-fdo-1.0
-    HINTS ${PC_WPEBACKEND_FDO_LIBDIR} ${PC_WPEBACKEND_FDO_LIBRARY_DIRS}
-)
-
-mark_as_advanced(WPEBACKEND_FDO_INCLUDE_DIRS WPEBACKEND_FDO_LIBRARIES)
-
-include(FindPackageHandleStandardArgs)
-find_package_handle_standard_args(WPEBACKEND_FDO REQUIRED_VARS WPEBACKEND_FDO_INCLUDE_DIRS WPEBACKEND_FDO_LIBRARIES)

Copied: trunk/Source/cmake/FindWPEBackend_fdo.cmake (from rev 258411, trunk/Source/cmake/FindWPEBackend-fdo.cmake) (0 => 258412)


--- trunk/Source/cmake/FindWPEBackend_fdo.cmake	                        (rev 0)
+++ trunk/Source/cmake/FindWPEBackend_fdo.cmake	2020-03-13 18:10:58 UTC (rev 258412)
@@ -0,0 +1,50 @@
+# - Try to find WPEBackend-fdo.
+# Once done, this will define
+#
+#  WPEBACKEND_FDO_FOUND - system has WPEBackend-fdo.
+#  WPEBACKEND_FDO_INCLUDE_DIRS - the WPEBackend-fdo include directories
+#  WPEBACKEND_FDO_LIBRARIES - link these to use WPEBackend-fdo.
+#
+# Copyright (C) 2016 Igalia S.L.
+#
+# Redistribution and use in source and binary forms, with or without
+# modification, are permitted provided that the following conditions
+# are met:
+# 1.  Redistributions of source code must retain the above copyright
+#     notice, this list of conditions and the following disclaimer.
+# 2.  Redistributions in binary form must reproduce the above copyright
+#     notice, this list of conditions and the following disclaimer in the
+#     documentation and/or other materials provided with the distribution.
+#
+# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER AND ITS CONTRIBUTORS ``AS
+# IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
+# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR ITS
+# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
+# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
+# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
+# WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
+# OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
+# ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+
+find_package(PkgConfig QUIET)
+pkg_check_modules(PC_WPEBACKEND_FDO QUIET wpebackend-fdo-1.0)
+
+find_path(WPEBACKEND_FDO_INCLUDE_DIRS
+    NAMES wpe/fdo.h
+    HINTS ${PC_WPEBACKEND_FDO_INCLUDEDIR} ${PC_WPEBACKEND_FDO_INCLUDE_DIRS}
+)
+
+find_library(WPEBACKEND_FDO_LIBRARIES
+    NAMES WPEBackend-fdo-1.0
+    HINTS ${PC_WPEBACKEND_FDO_LIBDIR} ${PC_WPEBACKEND_FDO_LIBRARY_DIRS}
+)
+
+mark_as_advanced(WPEBACKEND_FDO_INCLUDE_DIRS WPEBACKEND_FDO_LIBRARIES)
+
+include(FindPackageHandleStandardArgs)
+find_package_handle_standard_args(WPEBackend_fdo
+    REQUIRED_VARS WPEBACKEND_FDO_INCLUDE_DIRS WPEBACKEND_FDO_LIBRARIES
+    FOUND_VAR WPEBACKEND_FDO_FOUND
+    VERSION_VAR PC_WPEBACKEND_FDO_VERSION)

Modified: trunk/Source/cmake/OptionsGTK.cmake (258411 => 258412)


--- trunk/Source/cmake/OptionsGTK.cmake	2020-03-13 17:56:28 UTC (rev 258411)
+++ trunk/Source/cmake/OptionsGTK.cmake	2020-03-13 18:10:58 UTC (rev 258412)
@@ -218,7 +218,7 @@
         message(FATAL_ERROR "libwpe is required for USE_WPE_RENDERER")
     endif ()
 
-    find_package(WPEBackend-fdo 1.3.1)
+    find_package(WPEBackend_fdo 1.3.1)
     if (NOT WPEBACKEND_FDO_FOUND)
         message(FATAL_ERROR "WPEBackend-fdo is required for USE_WPE_RENDERER")
     endif ()

Modified: trunk/Source/cmake/OptionsWPE.cmake (258411 => 258412)


--- trunk/Source/cmake/OptionsWPE.cmake	2020-03-13 17:56:28 UTC (rev 258411)
+++ trunk/Source/cmake/OptionsWPE.cmake	2020-03-13 18:10:58 UTC (rev 258412)
@@ -168,7 +168,7 @@
 endif ()
 
 if (ENABLE_WPE_QT_API OR USE_WPE_VIDEO_PLANE_DISPLAY_DMABUF)
-    find_package(WPEBackend-fdo 1.5.0 REQUIRED)
+    find_package(WPEBackend_fdo 1.5.0 REQUIRED)
 endif ()
 
 add_definitions(-DBUILDING_WPE__=1)

Modified: trunk/Tools/ChangeLog (258411 => 258412)


--- trunk/Tools/ChangeLog	2020-03-13 17:56:28 UTC (rev 258411)
+++ trunk/Tools/ChangeLog	2020-03-13 18:10:58 UTC (rev 258412)
@@ -1,3 +1,12 @@
+2020-03-13  Konstantin Tokarev  <annu...@yandex.ru>
+
+        [CMake] Eleminate mismatches between Find* module names and variables they set
+        https://bugs.webkit.org/show_bug.cgi?id=208948
+
+        Reviewed by Michael Catanzaro.
+
+        * wpe/backends/CMakeLists.txt:
+
 2020-03-13  Aakash Jain  <aakash_j...@apple.com>
 
         [ews-app] reduce logging

Modified: trunk/Tools/wpe/backends/CMakeLists.txt (258411 => 258412)


--- trunk/Tools/wpe/backends/CMakeLists.txt	2020-03-13 17:56:28 UTC (rev 258411)
+++ trunk/Tools/wpe/backends/CMakeLists.txt	2020-03-13 18:10:58 UTC (rev 258412)
@@ -1,7 +1,7 @@
 find_package(Libxkbcommon 0.4.0 REQUIRED)
 find_package(Wayland REQUIRED)
 find_package(WaylandProtocols 1.12 REQUIRED)
-find_package(WPEBackend-fdo 1.3.0 REQUIRED)
+find_package(WPEBackend_fdo 1.3.0 REQUIRED)
 
 set(DERIVED_SOURCES_WPETOOLINGBACKENDS_DIR "${CMAKE_BINARY_DIR}/DerivedSources/WPEToolingBackends")
 
_______________________________________________
webkit-changes mailing list
webkit-changes@lists.webkit.org
https://lists.webkit.org/mailman/listinfo/webkit-changes

Reply via email to
--- trunk/Source/ThirdParty/libwebrtc/cmake/FindLibEvent.cmake	2020-03-13 17:56:28 UTC (rev 258411)
+++ trunk/Source/ThirdParty/libwebrtc/cmake/FindLibEvent.cmake	2020-03-13 18:10:58 UTC (rev 258412)
@@ -2,7 +2,7 @@
 # Once done, this will define
 #
 #  LIBEVENT_FOUND - system has libevent.
 #  EVENT_LIBRARY - link this to use libevent.
 #
 # Copyright (C) 2018 Igalia S.L.
 #
@@ -30,7 +30,7 @@
 find_package(PkgConfig)
 pkg_check_modules(PC_LIBEVENT libevent)
 
-find_library(EVENT_LIBRARY
+find_library(LIBEVENT_LIBRARY
     NAME event
     HINTS ${PC_LIBEVENT_LIBDIR}
 )
@@ -37,10 +37,10 @@
 
 include(FindPackageHandleStandardArgs)
 find_package_handle_standard_args(LibEvent
-    REQUIRED_VARS EVENT_LIBRARY
+    REQUIRED_VARS LIBEVENT_LIBRARY
     FOUND_VAR LIBEVENT_FOUND
     VERSION_VAR PC_LIBEVENT_VERSION)
 
 mark_as_advanced(
-    EVENT_LIBRARY
+    LIBEVENT_LIBRARY
 )
@@ -2,7 +2,7 @@
 #
 #  LIBEVENT_FOUND - system has libevent.
-#  EVENT_LIBRARY - link this to use libevent.
+#  LIBEVENT_LIBRARY - link this to use libevent.
 #
 # Copyright (C) 2018 Igalia S.L.

Copied: trunk/Source/ThirdParty/libwebrtc/cmake/FindLibOpus.cmake (from rev 258411, trunk/Source/ThirdParty/libwebrtc/cmake/FindOpus.cmake) (0 => 258412)

